summaryrefslogtreecommitdiff
path: root/src/vm/jitinterface.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/vm/jitinterface.cpp')
-rw-r--r--src/vm/jitinterface.cpp12
1 files changed, 5 insertions, 7 deletions
diff --git a/src/vm/jitinterface.cpp b/src/vm/jitinterface.cpp
index f1d41a266e..bf4abe12f5 100644
--- a/src/vm/jitinterface.cpp
+++ b/src/vm/jitinterface.cpp
@@ -5789,18 +5789,16 @@ void CEEInfo::getCallInfo(
}
}
- pResult->secureDelegateInvoke = FALSE;
+ pResult->wrapperDelegateInvoke = FALSE;
-#ifdef FEATURE_STUBS_AS_IL
if (m_pMethodBeingCompiled->IsDynamicMethod())
{
auto pMD = m_pMethodBeingCompiled->AsDynamicMethodDesc();
- if (pMD->IsILStub() && pMD->IsSecureDelegateStub())
+ if (pMD->IsILStub() && pMD->IsWrapperDelegateStub())
{
- pResult->secureDelegateInvoke = TRUE;
+ pResult->wrapperDelegateInvoke = TRUE;
}
}
-#endif
EE_TO_JIT_TRANSITION();
}
@@ -10327,8 +10325,8 @@ void CEEInfo::getEEInfo(CORINFO_EE_INFO *pEEInfoOut)
pEEInfoOut->offsetOfDelegateInstance = OFFSETOF__DelegateObject__target;
pEEInfoOut->offsetOfDelegateFirstTarget = OFFSETOF__DelegateObject__methodPtr;
- // Secure delegate offsets
- pEEInfoOut->offsetOfSecureDelegateIndirectCell = OFFSETOF__DelegateObject__methodPtrAux;
+ // Wrapper delegate offsets
+ pEEInfoOut->offsetOfWrapperDelegateIndirectCell = OFFSETOF__DelegateObject__methodPtrAux;
// Remoting offsets
pEEInfoOut->offsetOfTransparentProxyRP = (DWORD)-1;